//***************** (c) 2008 BTC Korporacja ***********************************
//                     http://www kamami.com
// PROJECT  : RTC
// BOARD    : ZL16AVR (with ATmega88 in socket U1)
// COMPILER : WinAVR 20080610
//
//******************************************************************************
//
//    THE SOFTWARE INCLUDED IN THIS FILE IS FOR GUIDANCE ONLY.
//    BTC KORPORACJA SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT
//    OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
//    FROM USE OF THIS SOFTWARE.
//
//******************************************************************************
//
// DESCRIPTION :
//    Simple I2C communication demo.
//    Read time from RTC (U6 - M41T00)
//    and transmit it to PC via UART.
//
//    Settings and connections on ZL16AVR:
//        SCL (U6 RTC/con7) - PC0 (con17)
//        SDA (U6 RTC/con7) - PC1 (con17)
//
//      if RS232 cable connected:
//        RxD (con7) - PD0 (con18)
//        TxD (con7) - PD1 (con18)
//
//      if UART2USB converter (ZL1USB_A or ZL4USB) connected:
//        RxU (con7) - PD0 (con18)
//        TxU (con7) - PD1 (con18)
//
//******************************************************************************
#ifndef F_CPU  
  #define F_CPU   16000000    // 16 MHz - turn on external resonator (fuse bits)
#endif

#include <avr/io.h>
#include <util/delay.h>
#include <stdlib.h>
#include "USART.h"
#include "TWI.h"
//-------------------------------------
// main program
//-------------------------------------
int main(void)
{
char j, B1;

DDRD |= (1 << PD1);

TWI_Init();
USART_Init(BAUD(1200));

USART_PutString("\r");
USART_PutString("*************************\r");
USART_PutString("**     ZL16AVR  RTC    **\r");
USART_PutString("**    www.kamami.com   **\r");
USART_PutString("*************************\r");

do{
USART_PutString("M41T00\r");

TWI_Start();                        // start transmission
TWI_Write(0xD0);                    // write addres of M41T00
TWI_Write(0x02);                    // select hours register
TWI_Start();                        // repeated start
TWI_Write(0xD1);                    // write address for reading data
B1 = TWI_Read(NACK);                // read hours register
TWI_Stop();                         // stop transmission    

USART_PutChar(((B1>>4)&3)+'0');     // convert hours to ASCII char
USART_PutChar((B1&15)+'0');         // convert hours to ASCII char
USART_PutChar(':');                         

TWI_Start();                        // start transmission  
TWI_Write(0xD0);                    // write addres of M41T00
TWI_Write(0x01);                    // select minutes register  
TWI_Start();                        // repeated start
TWI_Write(0xD1);                    // write address for reading data
B1 = TWI_Read(NACK);                // read minutes register
TWI_Stop();                         // stop transmission

USART_PutChar(((B1>>4)&7)+'0');     // convert minutes to ASCII char
USART_PutChar((B1&15)+'0');         // convert minutes to ASCII char
USART_PutChar(':');

TWI_Start();                        // start transmission
TWI_Write(0xD0);                    // write addres of M41T00
TWI_Write(0x00);                    // select seconds register
TWI_Start();                        // repeated start         
TWI_Write(0xD1);                    // write address for reading data
B1 = TWI_Read(NACK);                // read minutes register
TWI_Stop();                         // stop transmission

USART_PutChar(((B1>>4)&7)+'0');     // convert seconds to ASCII char
USART_PutChar((B1&15)+'0');         // convert seconds to ASCII char
USART_PutChar('\r');

USART_PutString("------------------------------------------\r");

for(j = 0; j < 20; j++)             //  
  _delay_ms(10);                    // wait 200 miliseconds
}while(1);
return 0;
}
//-------------------------------------
// End of file
//-------------------------------------
